@@ -1,6 +1,7 @@
 package api
 
 import (
+	"fmt"
 	"syscall"
 	"time"
 )
@@ -1314,12 +1315,18 @@ type V1Machine struct {
 
 	CreatedAt string `json:"created_at"`
 
+	UpdatedAt string `json:"updated_at"`
+
 	Config *MachineConfig `json:"config"`
 
 	Events     []*MachineEventt `json:"events,omitempty"`
 	LeaseNonce string
 }
 
+func (m V1Machine) FullImageRef() string {
+	return fmt.Sprintf("%s:%s", m.ImageRef.Repository, m.ImageRef.Tag)
+}
+
 type V1MachineStop struct {
 	ID      string        `json:"id"`
 	Signal  Signal        `json:"signal,omitempty"`
