@@ -105,7 +105,7 @@ func DeployWithConfig(ctx context.Context, appConfig *app.Config) (err error) {
 	var release *api.Release
 	var releaseCommand *api.ReleaseCommand
 
-	if appConfig.Version >= app.MachinesVersion {
+	if appConfig.PlatformVersion >= app.MachinesVersion {
 		return createMachinesRelease(ctx, appConfig, img)
 	} else {
 		release, releaseCommand, err = createRelease(ctx, appConfig, img)
@@ -196,7 +196,7 @@ func determineImage(ctx context.Context, appConfig *app.Config) (img *imgsrc.Dep
 	daemonType := imgsrc.NewDockerDaemonType(!flag.GetRemoteOnly(ctx), !flag.GetLocalOnly(ctx))
 
 	var appName string = app.NameFromContext(ctx)
-	if appConfig.AppName != "" {
+	if appConfig.AppName != "" && appName == "" {
 		appName = appConfig.AppName
 	}
 
